@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Auxiliary.cpp 1891 2006-10-23 15:45:46Z svn $
+ * $Id: Auxiliary.cpp 1981 2006-11-12 06:40:26Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -31,7 +31,7 @@
 #include "Message.h"
 #include "Macro.h"
 
-#include "apr_atomic.h"
+#include "AtomicWrapper.h"
 #include "apr_file_info.h"
 #include "apr_strings.h"
 #include "apr_time.h"
@@ -47,7 +47,7 @@
 
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: Auxiliary.cpp 1891 2006-10-23 15:45:46Z svn $");
+SOURCE_INFO_ADD("$Id: Auxiliary.cpp 1981 2006-11-12 06:40:26Z svn $");
 
 void init_atomic(apr_pool_t *pool)
 {
