@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: fast_bbs_handler.cpp 1887 2006-10-22 18:49:12Z svn $
+ * $Id: fast_bbs_handler.cpp 1951 2006-11-08 11:31:58Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -55,7 +55,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: fast_bbs_handler.cpp 1887 2006-10-22 18:49:12Z svn $");
+SOURCE_INFO_ADD("$Id: fast_bbs_handler.cpp 1951 2006-11-08 11:31:58Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -67,11 +67,6 @@ static const char SUBJECT_VAR_NAME[]            = "SUBJECT";
 static const char COMMENT_COUNT_VAR_NAME[]      = "COMMENT_COUNT";
 static const char COMMENT_LIST_VAR_NAME[]       = "COMMENT_LIST";
 
-static const char IMAGE_EXT_VAR_NAME[]          = "IMAGE_EXT";
-static const char IMAGE_SIZE_VAR_NAME[]         = "IMAGE_SIZE";
-static const char THUMBNAIL_WIDTH_VAR_NAME[]    = "THUMBNAIL_WIDTH";
-static const char THUMBNAIL_HEIGHT_VAR_NAME[]   = "THUMBNAIL_HEIGHT";
-
 static const char THREAD_INFO_LIST_VAR_NAME[]   = "THREAD_INFO_LIST";
 static const char THREAD_LIST_VAR_NAME[    ]    = "THREAD_LIST";
 static const char THREAD_LIST_SIZE_VAR_NAME[]   = "THREAD_LIST_SIZE";
@@ -285,17 +280,6 @@ static int comment(typename Response::Handle *r, BBSConfig *config,
         var_creator.create(THREAD_ID_VAR_NAME, bcomment_iter->get_id());
         var_creator.create(SUBJECT_VAR_NAME, bcomment_iter->get_subject());
 
-        var_creator.create(IMAGE_SIZE_VAR_NAME,
-                           bcomment_iter->get_image_size());
-        if (bcomment_iter->get_image_size() != 0) {
-            var_creator.create(IMAGE_EXT_VAR_NAME,
-                               bcomment_iter->get_image_ext());
-            var_creator.create(THUMBNAIL_WIDTH_VAR_NAME,
-                               bcomment_iter->get_thumbnail_width());
-            var_creator.create(THUMBNAIL_HEIGHT_VAR_NAME,
-                               bcomment_iter->get_thumbnail_height());
-        }
-
         var_creator.create(COMMENT_COUNT_VAR_NAME,
                            bcomment_iter->get_comment_count());
         var_creator.create
@@ -375,7 +359,7 @@ static int file(typename Response::Handle *r, BBSConfig *config,
     file_name = get_word(r->pool, &arg, ARG_SEPARATE_STR[0]);
     thread_id_str = apr_pstrdup(r->pool, file_name);
     thread_id = static_cast<apr_size_t>
-        (apr_atoi64(get_word(r->pool, &thread_id_str, FILE_EXT_SEPARATOR[0])));
+        (apr_atoi64(get_word(r->pool, &thread_id_str, FILE_TOKEN_SEPARATOR[0])));
 
     try {
         file_path = BBSThreadIO::get_file_path(r->pool, config->file_dir_path,
@@ -470,6 +454,7 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
 {
     int status;
     apr_array_header_t *content_array;
+    const char *image_temp_path;
 
     if (!Response::is_post_method(r)) {
         return HTTP_BAD_REQUEST;
@@ -484,6 +469,7 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
     }
 
     typename Response::Writer o(r);
+    image_temp_path = NULL;
     try {
         apr_size_t thread_id;
         const char *name;
@@ -493,20 +479,31 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
         apr_time_t time;
         bool is_age;
         RequestReader::progress_t progress;
+        BBSThread::image_t image;
+        apr_uint16_t comment_no;
 
         typename Response::Reader i(&progress, r);
         RFC1867Parser<typename Response::Reader> parser
             (r->pool, i, config->temp_dir_path,
-             TRD_MAX_MESSAGE_SIZE, 0, PST_MAX_ITEM_COUNT);
+             TRD_MAX_MESSAGE_SIZE, TRD_MAX_IMAGE_SIZE,
+             PST_MAX_ITEM_COUNT);
 
         content_array = parser.parse(Response::get_content_type(r),
                                      Response::get_content_size(r));
 
         get_post_comment_param<typename Response::Reader>
             (r->pool, content_array,
-             &thread_id, &name, &trip, &email, &message, &time, &is_age);
-        config->get_thread_manager()->add_comment
-            (thread_id, name, trip, email, message, time, is_age);
+             &thread_id, &name, &trip, &email, &message,
+             &image, &image_temp_path, &time, &is_age);
+
+
+        comment_no = config->get_thread_manager()->add_comment
+            (thread_id, name, trip, email, message, &image, time, is_age);
+
+        if (image.size != 0) {
+            commit_image_file(r->pool, config->file_dir_path,
+                              thread_id, comment_no, &image, image_temp_path);
+        }
 
         regist_post(config, Response::get_remote_ip(r));
 
@@ -522,6 +519,10 @@ static int post_comment(typename Response::Handle *r, BBSConfig *config,
               ARG_ANCHOR_STR, POST_COMMENT_COMMAND,
               NULL));
     } catch(const char *message) {
+        if (image_temp_path != NULL) {
+            apr_file_remove(image_temp_path, r->pool);
+        }
+
         return error_with_log<Response>(r, o, config, message);
     }
     o.finish();
@@ -560,27 +561,29 @@ static int post_thread(typename Response::Handle *r, BBSConfig *config,
         BBSThread::image_t image;
 
         typename Response::Reader i(&progress, r);
-        RFC1867Parser<typename Response::Reader>
-            parser(r->pool, i, config->temp_dir_path,
-                   TRD_MAX_MESSAGE_SIZE, TRD_MAX_IMAGE_SIZE,
-                   PST_MAX_ITEM_COUNT);
+        RFC1867Parser<typename Response::Reader> parser
+            (r->pool, i, config->temp_dir_path,
+             TRD_MAX_MESSAGE_SIZE, TRD_MAX_IMAGE_SIZE,
+             PST_MAX_ITEM_COUNT);
 
         content_array = parser.parse(Response::get_content_type(r),
                                      Response::get_content_size(r));
 
         get_post_thread_param<typename Response::Reader>
             (r->pool, content_array,
-             &subject, &image, &image_temp_path,
-             &name, &trip, &email, &message, &time, &is_age);
+             &subject, &name, &trip, &email, &message,
+             &image, &image_temp_path, &time, &is_age);
 
         thread_id = config->get_thread_manager()->create_thread
-            (subject, &image, name, trip, email, message, time, is_age);
+            (subject, name, trip, email, message, &image, time, is_age);
 
         if (image.size != 0) {
-            commit_image_file(r->pool, config->file_dir_path, thread_id,
-                              &image, image_temp_path);
+            commit_image_file(r->pool, config->file_dir_path,
+                              thread_id, 1, &image, image_temp_path);
         }
 
+        regist_post(config, Response::get_remote_ip(r));
+
         return redirect<Response>
             (r, o,
              apr_pstrcat
